@@ -1,7 +1,9 @@
 mod bool;
+mod btreemap;
 #[cfg(feature = "chrono")]
 mod datetime;
 mod floats;
+mod hashmap;
 mod integers;
 mod optional;
 mod string;
