@@ -85,6 +85,7 @@ pub trait ToJSON: Type {
 }
 
 impl<T: Type> Type for Arc<T> {
+    const IS_REQUIRED: bool = T::IS_REQUIRED;
     type RawValueType = T::RawValueType;
 
     fn name() -> Cow<'static, str> {
@@ -95,6 +96,10 @@ impl<T: Type> Type for Arc<T> {
         T::schema_ref()
     }
 
+    fn register(registry: &mut Registry) {
+        T::register(registry);
+    }
+
     fn as_raw_value(&self) -> Option<&Self::RawValueType> {
         self.as_ref().as_raw_value()
     }
@@ -123,6 +128,7 @@ impl<T: ToJSON> ToJSON for Arc<T> {
 }
 
 impl<T: Type> Type for Box<T> {
+    const IS_REQUIRED: bool = T::IS_REQUIRED;
     type RawValueType = T::RawValueType;
 
     fn name() -> Cow<'static, str> {
@@ -133,6 +139,10 @@ impl<T: Type> Type for Box<T> {
         T::schema_ref()
     }
 
+    fn register(registry: &mut Registry) {
+        T::register(registry);
+    }
+
     fn as_raw_value(&self) -> Option<&Self::RawValueType> {
         self.as_ref().as_raw_value()
     }
